-- Default configuration file
-- Copy to TBD to override values. This file will be overridden on update.
local awful = require("awful")
local naughty = require("naughty")


local config = {}


--
-- Awesome WM
--
config.awesome = {
    -- Enable window autofocus on mouse hover
    autofocus = true,

    -- Enable hotkeys help widget for VIM and other apps
    -- when client with a matching name is opened:
    hotkeys_popup = true,

    -- Terminal
    terminal = "terminator",

    -- Default terminal editor
    -- editor = "vi",
    editor = os.getenv("EDITOR") or "nano",
    editor_cmd = config.awesome.terminal .. " -e " .. config.awesome.editor,
}


--
-- Keys / Hotkeys / Shortcuts
--
-- To disable a shortcut, simply remove it (tip: comment it out with a leading "--")
--
config.keys = {
    -- Main modifier key for meta hotkeys like moving windows or locking the session
    -- Usually, Mod4 is the key with a logo between Control and Alt.
    modkey = "Mod4",

    -- Hotkeys globally available (through the entire OS, regardless of what's focused)
    globalkeys = {
        media_control = {
            --
            -- Media and volume controls
            -- See media_control.lua
            --

            -- Raise volume
            raiseVolume = "XF86AudioRaiseVolume",

            -- Lower volume
            lowerVolume = "XF86AudioLowerVolume",

            -- Toggle mute
            toggleMute = "XF86AudioMute",

            -- Toggle Play / Pause
            playPause = "XF86AudioPlay",

            -- Next track
            nextTrack = "XF86AudioNext",

            -- Previous track
            previousTrack = "XF86AudioPrev",
        },
    },
}


--
-- Widgets
--
config.widgets = {
    -- Enable/disable the system resources monitoring widget
    system_resources = true,
}


--
-- Auto start custom applications
--
config.autostart = {
    -- Network manager widget
    {
        "nm-applet --help", -- Verification command that will be checked before spawning the next command
        "nm-applet", -- The app
    },

    -- Screenshot utility
    "flameshot",
}


-- Theme
-- Change to gears.filesystem.get_themes_dir() .. "default/theme.lua" to use default awesome theme
config.theme = awful.util.getdir("config") .. "/default_theme.lua"

-- Screenshot utility
config.screenshot_utility_command = "flameshot gui"

-- Keyboard layout
config.kbSwitchCmd = "setxkbmap"
config.kbLayouts = { "fr", "us" }

-- Run menu
config.runMenu = "rofi -show run -config " .. awful.util.getdir("config") .. "/rofi/themes/paper-float.rasi"
config.windowSwitcher = "rofi -show window -config " .. awful.util.getdir("config") .. "/rofi/themes/paper-float.rasi"

-- Media control
config.volume_osd_timeout = 2

-- System resources widget
config.system_resources_widget_screens = { 1, 2 }
config.system_resources_widget_refresh_interval = 1.5 -- In seconds


-- Awesome tweaks
naughty.config.defaults.timeout = 15


return config
